diff --git a/core/modules/comment/src/Plugin/views/filter/NodeComment.php b/core/modules/comment/src/Plugin/views/filter/NodeComment.php
index fe041bd..e4e566e 100644
--- a/core/modules/comment/src/Plugin/views/filter/NodeComment.php
+++ b/core/modules/comment/src/Plugin/views/filter/NodeComment.php
@@ -20,7 +20,7 @@
 class NodeComment extends InOperator {
 
   public function getValueOptions() {
-    $this->value_options = array(
+    $this->valueOptions = array(
       CommentItemInterface::HIDDEN => t('Hidden'),
       CommentItemInterface::CLOSED => t('Closed'),
       CommentItemInterface::OPEN => t('Open'),
diff --git a/core/modules/field/src/Plugin/views/filter/FieldList.php b/core/modules/field/src/Plugin/views/filter/FieldList.php
index 16024fb..8be06c6 100644
--- a/core/modules/field/src/Plugin/views/filter/FieldList.php
+++ b/core/modules/field/src/Plugin/views/filter/FieldList.php
@@ -21,7 +21,7 @@ class FieldList extends ManyToOne {
   public function getValueOptions() {
     $field_storage_definitions = \Drupal::entityManager()->getFieldStorageDefinitions($this->definition['entity_type']);
     $field = $field_storage_definitions[$this->definition['field_name']];
-    $this->value_options = list_allowed_values($field);
+    $this->valueOptions = list_allowed_values($field);
   }
 
 }
diff --git a/core/modules/file/src/Plugin/views/filter/Status.php b/core/modules/file/src/Plugin/views/filter/Status.php
index 963e8a0..d28cf94 100644
--- a/core/modules/file/src/Plugin/views/filter/Status.php
+++ b/core/modules/file/src/Plugin/views/filter/Status.php
@@ -19,8 +19,8 @@
 class Status extends InOperator {
 
   public function getValueOptions() {
-    if (!isset($this->value_options)) {
-      $this->value_options = _views_file_status();
+    if (!isset($this->valueOptions)) {
+      $this->valueOptions = _views_file_status();
     }
   }
 
diff --git a/core/modules/language/src/Plugin/views/filter/LanguageFilter.php b/core/modules/language/src/Plugin/views/filter/LanguageFilter.php
index d03ea6f..8e96f2f 100644
--- a/core/modules/language/src/Plugin/views/filter/LanguageFilter.php
+++ b/core/modules/language/src/Plugin/views/filter/LanguageFilter.php
@@ -19,14 +19,14 @@
 class LanguageFilter extends InOperator {
 
   public function getValueOptions() {
-    if (!isset($this->value_options)) {
+    if (!isset($this->valueOptions)) {
       $this->value_title = t('Language');
       $languages = array(
         '***CURRENT_LANGUAGE***' => t("Current user's language"),
         '***DEFAULT_LANGUAGE***' => t("Default site language"),
       );
       $languages = array_merge($languages, views_language_list());
-      $this->value_options = $languages;
+      $this->valueOptions = $languages;
     }
   }
 
diff --git a/core/modules/system/tests/Drupal/system/Tests/Menu/SystemLocalTasksTest.php b/core/modules/system/tests/Drupal/system/Tests/Menu/SystemLocalTasksTest.php
deleted file mode 100644
index 9cd7ebc..0000000
--- a/core/modules/system/tests/Drupal/system/Tests/Menu/SystemLocalTasksTest.php
+++ /dev/null
@@ -1,84 +0,0 @@
-<?php
-
-/**
- * @file
- * Contains \Drupal\system\Tests\Menu\SystemLocalTasksTest.
- */
-
-namespace Drupal\system\Tests\Menu;
-
-use Drupal\Core\Extension\Extension;
-use Drupal\Tests\Core\Menu\LocalTaskIntegrationTest;
-
-/**
- * Tests existence of system local tasks.
- *
- * @group Drupal
- * @group System
- */
-class SystemLocalTasksTest extends LocalTaskIntegrationTest {
-
-  /**
-   * The mocked theme handler.
-   *
-   * @var \Drupal\Core\Extension\ThemeHandlerInterface|\PHPUnit_Framework_MockObject_MockObject
-   */
-  protected $themeHandler;
-
-  /**
-   * {@inheritdoc}
-   */
-  public static function getInfo() {
-    return array(
-      'name' => 'System local tasks',
-      'description' => '',
-      'group' => 'System',
-    );
-  }
-
-  /**
-   * {@inheritdoc}
-   */
-  public function setUp() {
-    parent::setUp();
-
-    $this->directoryList = array(
-      'system' => 'core/modules/system',
-    );
-
-    $this->themeHandler = $this->getMock('Drupal\Core\Extension\ThemeHandlerInterface');
-
-    $theme = new Extension('theme', DRUPAL_ROOT . '/core/themes/bartik', 'bartik.info.yml');
-    $theme->status = 1;
-    $theme->info = array('name' => 'bartik');
-    $this->themeHandler->expects($this->any())
-      ->method('listInfo')
-      ->will($this->returnValue(array(
-        'bartik' => $theme,
-      )));
-    $this->container->set('theme_handler', $this->themeHandler);
-  }
-
-  /**
-   * Tests local task existence.
-   *
-   * @dataProvider getSystemAdminRoutes
-   */
-  public function testSystemAdminLocalTasks($route, $expected) {
-    $this->assertLocalTasks($route, $expected);
-  }
-
-  /**
-   * Provides a list of routes to test.
-   */
-  public function getSystemAdminRoutes() {
-    return array(
-      array('system.admin_content', array(array('system.admin_content'))),
-      array('system.theme_settings_theme', array(
-        array('system.themes_page', 'system.theme_settings'),
-        array('system.theme_settings_global', 'system.theme_settings_theme:bartik'),
-      )),
-    );
-  }
-
-}
diff --git a/core/modules/user/src/Plugin/views/filter/Permissions.php b/core/modules/user/src/Plugin/views/filter/Permissions.php
index c0a651d..5925cad 100644
--- a/core/modules/user/src/Plugin/views/filter/Permissions.php
+++ b/core/modules/user/src/Plugin/views/filter/Permissions.php
@@ -54,7 +54,7 @@ public static function create(ContainerInterface $container, array $configuratio
   }
 
   public function getValueOptions() {
-    if (!isset($this->value_options)) {
+    if (!isset($this->valueOptions)) {
       $module_info = system_get_info('module');
 
       // Get a list of all the modules implementing a hook_permission() and sort by
@@ -65,17 +65,17 @@ public function getValueOptions() {
       }
       asort($modules);
 
-      $this->value_options = array();
+      $this->valueOptions = array();
       foreach ($modules as $module => $display_name) {
         if ($permissions = $this->moduleHandler->invoke($module, 'permission')) {
           foreach ($permissions as $perm => $perm_item) {
-            $this->value_options[$display_name][$perm] = String::checkPlain(strip_tags($perm_item['title']));
+            $this->valueOptions[$display_name][$perm] = String::checkPlain(strip_tags($perm_item['title']));
           }
         }
       }
     }
     else {
-      return $this->value_options;
+      return $this->valueOptions;
     }
   }
 
diff --git a/core/modules/user/src/Plugin/views/filter/Roles.php b/core/modules/user/src/Plugin/views/filter/Roles.php
index 3fdb63c..91d73ca 100644
--- a/core/modules/user/src/Plugin/views/filter/Roles.php
+++ b/core/modules/user/src/Plugin/views/filter/Roles.php
@@ -19,8 +19,8 @@
 class Roles extends ManyToOne {
 
   public function getValueOptions() {
-    $this->value_options = user_role_names(TRUE);
-    unset($this->value_options[DRUPAL_AUTHENTICATED_RID]);
+    $this->valueOptions = user_role_names(TRUE);
+    unset($this->valueOptions[DRUPAL_AUTHENTICATED_RID]);
   }
 
   /**
diff --git a/core/modules/user/src/Tests/Views/HandlerFilterPermissionTest.php b/core/modules/user/src/Tests/Views/HandlerFilterPermissionTest.php
index 970ea70..b880bd0 100644
--- a/core/modules/user/src/Tests/Views/HandlerFilterPermissionTest.php
+++ b/core/modules/user/src/Tests/Views/HandlerFilterPermissionTest.php
@@ -85,13 +85,13 @@ public function testFilterPermission() {
     $view->filter['permission']->getValueOptions();
 
     // Test the value options.
-    $value_options = $view->filter['permission']->getValueOptions();
+    $valueOptions = $view->filter['permission']->getValueOptions();
     foreach (array('system' => 'System', 'user' => 'User') as $module => $title) {
       $expected = array_map(function ($permission) {
         return String::checkPlain(strip_tags($permission['title']));
       }, $this->container->get('module_handler')->invoke($module, 'permission'));
 
-      $this->assertEqual($expected, $value_options[$title], 'Ensure the all permissions are available');
+      $this->assertEqual($expected, $valueOptions[$title], 'Ensure the all permissions are available');
     }
   }
 
diff --git a/core/modules/views/src/Plugin/views/filter/Bundle.php b/core/modules/views/src/Plugin/views/filter/Bundle.php
index 2691541..dde00b5 100644
--- a/core/modules/views/src/Plugin/views/filter/Bundle.php
+++ b/core/modules/views/src/Plugin/views/filter/Bundle.php
@@ -48,7 +48,7 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
    * Overrides \Drupal\views\Plugin\views\filter\InOperator::getValueOptions().
    */
   public function getValueOptions() {
-    if (!isset($this->value_options)) {
+    if (!isset($this->valueOptions)) {
       $types = entity_get_bundles($this->entityTypeId);
       $this->value_title = t('@entity types', array('@entity' => $this->entityType->getLabel()));
 
@@ -58,10 +58,10 @@ public function getValueOptions() {
       }
 
       asort($options);
-      $this->value_options = $options;
+      $this->valueOptions = $options;
     }
 
-    return $this->value_options;
+    return $this->valueOptions;
   }
 
   /**
diff --git a/core/modules/views/src/Tests/Entity/FilterEntityBundleTest.php b/core/modules/views/src/Tests/Entity/FilterEntityBundleTest.php
index d950a6a..0a9fa3a 100644
--- a/core/modules/views/src/Tests/Entity/FilterEntityBundleTest.php
+++ b/core/modules/views/src/Tests/Entity/FilterEntityBundleTest.php
@@ -81,7 +81,7 @@ public function testFilterEntity() {
     // Test we have all the results, with all types selected.
     $this->assertEqual(count($view->result), $this->entities['count']);
 
-    // Test the value_options of the filter handler.
+    // Test the valueOptions of the filter handler.
     $expected = array();
 
     foreach ($this->entityBundles as $key => $info) {

diff --git a/core/modules/taxonomy/src/Plugin/views/filter/TaxonomyIndexTid.php b/core/modules/taxonomy/src/Plugin/views/filter/TaxonomyIndexTid.php
index 2c708ea..b446aa9 100644
--- a/core/modules/taxonomy/src/Plugin/views/filter/TaxonomyIndexTid.php
+++ b/core/modules/taxonomy/src/Plugin/views/filter/TaxonomyIndexTid.php
@@ -348,8 +348,8 @@ public function buildExposeForm(&$form, &$form_state) {
   }
 
   public function adminSummary() {
-    // set up $this->value_options for the parent summary
-    $this->value_options = array();
+    // set up $this->valueOptions for the parent summary
+    $this->valueOptions = array();
 
     if ($this->value) {
       $this->value = array_filter($this->value);
@@ -358,7 +358,7 @@ public function adminSummary() {
         ->condition('td.tid', $this->value)
         ->execute();
       foreach ($result as $term_record) {
-        $this->value_options[$term_record->tid] = $term_record->name;
+        $this->valueOptions[$term_record->tid] = $term_record->name;
       }
     }
     return parent::adminSummary();
diff --git a/core/modules/user/src/Plugin/views/filter/Name.php b/core/modules/user/src/Plugin/views/filter/Name.php
index 0d1b5fc..4212d1c 100644
--- a/core/modules/user/src/Plugin/views/filter/Name.php
+++ b/core/modules/user/src/Plugin/views/filter/Name.php
@@ -148,17 +148,17 @@ protected function valueSubmit($form, &$form_state) {
   public function getValueOptions() { }
 
   public function adminSummary() {
-    // set up $this->value_options for the parent summary
-    $this->value_options = array();
+    // set up $this->valueOptions for the parent summary
+    $this->valueOptions = array();
 
     if ($this->value) {
       $result = entity_load_multiple_by_properties('user', array('uid' => $this->value));
       foreach ($result as $account) {
         if ($account->id()) {
-          $this->value_options[$account->id()] = $account->label();
+          $this->valueOptions[$account->id()] = $account->label();
         }
         else {
-          $this->value_options[$account->id()] = 'Anonymous'; // Intentionally NOT translated.
+          $this->valueOptions[$account->id()] = 'Anonymous'; // Intentionally NOT translated.
         }
       }
     }
diff --git a/core/modules/views/src/Plugin/views/filter/BooleanOperator.php b/core/modules/views/src/Plugin/views/filter/BooleanOperator.php
index 1158575..3696131 100644
--- a/core/modules/views/src/Plugin/views/filter/BooleanOperator.php
+++ b/core/modules/views/src/Plugin/views/filter/BooleanOperator.php
@@ -89,7 +89,7 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
     elseif (isset($this->definition['accept_null'])) {
       $this->accept_null = (bool) $this->definition['accept_null'];
     }
-    $this->value_options = NULL;
+    $this->valueOptions = NULL;
   }
 
   /**
@@ -107,19 +107,19 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
   public function getValueOptions() {
     if (isset($this->definition['type'])) {
       if ($this->definition['type'] == 'yes-no') {
-        $this->value_options = array(1 => t('Yes'), 0 => t('No'));
+        $this->valueOptions = array(1 => t('Yes'), 0 => t('No'));
       }
       if ($this->definition['type'] == 'on-off') {
-        $this->value_options = array(1 => t('On'), 0 => t('Off'));
+        $this->valueOptions = array(1 => t('On'), 0 => t('Off'));
       }
       if ($this->definition['type'] == 'enabled-disabled') {
-        $this->value_options = array(1 => t('Enabled'), 0 => t('Disabled'));
+        $this->valueOptions = array(1 => t('Enabled'), 0 => t('Disabled'));
       }
     }
 
     // Provide a fallback if the above didn't set anything.
-    if (!isset($this->value_options)) {
-      $this->value_options = array(1 => t('True'), 0 => t('False'));
+    if (!isset($this->valueOptions)) {
+      $this->valueOptions = array(1 => t('True'), 0 => t('False'));
     }
   }
 
@@ -132,7 +132,7 @@ protected function defineOptions() {
   }
 
   protected function valueForm(&$form, &$form_state) {
-    if (empty($this->value_options)) {
+    if (empty($this->valueOptions)) {
       // Initialize the array of possible values for this filter.
       $this->getValueOptions();
     }
@@ -147,7 +147,7 @@ protected function valueForm(&$form, &$form_state) {
     $form['value'] = array(
       '#type' => $filter_form_type,
       '#title' => $this->value_value,
-      '#options' => $this->value_options,
+      '#options' => $this->valueOptions,
       '#default_value' => $this->value,
     );
     if (!empty($this->options['exposed'])) {
@@ -175,14 +175,14 @@ public function adminSummary() {
     if (!empty($this->options['exposed'])) {
       return t('exposed');
     }
-    if (empty($this->value_options)) {
+    if (empty($this->valueOptions)) {
       $this->getValueOptions();
     }
     // Now that we have the valid options for this filter, just return the
     // human-readable label based on the current value.  The value_options
     // array is keyed with either 0 or 1, so if the current value is not
     // empty, use the label for 1, and if it's empty, use the label for 0.
-    return $this->value_options[!empty($this->value)];
+    return $this->valueOptions[!empty($this->value)];
   }
 
   public function defaultExposeOptions() {
@@ -175,14 +175,14 @@ public function adminSummary() {
     }
     // Now that we have the valid options for this filter, just return the
-    // human-readable label based on the current value.  The value_options
+    // human-readable label based on the current value.  The valueOptions
     // array is keyed with either 0 or 1, so if the current value is not
     // empty, use the label for 1, and if it's empty, use the label for 0.
diff --git a/core/modules/views/src/Plugin/views/filter/InOperator.php b/core/modules/views/src/Plugin/views/filter/InOperator.php
index 6c54650..e76a531 100644
--- a/core/modules/views/src/Plugin/views/filter/InOperator.php
+++ b/core/modules/views/src/Plugin/views/filter/InOperator.php
@@ -30,7 +30,7 @@ class InOperator extends FilterPluginBase {
    * @var array
    * Stores all operations which are available on the form.
    */
-  var $value_options = NULL;
+  public $valueOptions = NULL;
 
   /**
    * Overrides \Drupal\views\Plugin\views\filter\FilterPluginBase::init().
@@ -38,8 +38,8 @@ class InOperator extends FilterPluginBase {
   public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
     parent::init($view, $display, $options);
 
-    $this->value_title = t('Options');
-    $this->value_options = NULL;
+    $this->valueTitle = t('Options');
+    $this->valueOptions = NULL;
   }
 
   /**
@@ -51,26 +51,26 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
    * possible.
    *
    * @return
    *   Return the stored values in $this->value_options if someone expects it.
    */
   public function getValueOptions() {
-    if (isset($this->value_options)) {
+    if (isset($this->valueOptions)) {
       return;
     }
 
     if (isset($this->definition['options callback']) && is_callable($this->definition['options callback'])) {
       if (isset($this->definition['options arguments']) && is_array($this->definition['options arguments'])) {
-        $this->value_options = call_user_func_array($this->definition['options callback'], $this->definition['options arguments']);
+        $this->valueOptions = call_user_func_array($this->definition['options callback'], $this->definition['options arguments']);
       }
       else {
-        $this->value_options = call_user_func($this->definition['options callback']);
+        $this->valueOptions = call_user_func($this->definition['options callback']);
       }
     }
     else {
-      $this->value_options = array(t('Yes'), t('No'));
+      $this->valueOptions = array(t('Yes'), t('No'));
     }
 
-    return $this->value_options;
+    return $this->valueOptions;
   }
 
   public function defaultExposeOptions() {
@@ -78,8 +78,8 @@ public function defaultExposeOptions() {
     $this->options['expose']['reduce'] = FALSE;
   }
 
-  public function buildExposeForm(&$form, &$form_state) {
-    parent::buildExposeForm($form, $form_state);
+  public function buildExposeForm(&$form, &$formState) {
+    parent::buildExposeForm($form, $formState);
     $form['expose']['reduce'] = array(
       '#type' => 'checkbox',
       '#title' => t('Limit list to selected items'),
@@ -164,24 +164,24 @@ protected function operatorValues($values = 1) {
     return $options;
   }
 
-  protected function valueForm(&$form, &$form_state) {
+  protected function valueForm(&$form, &$formState) {
     $form['value'] = array();
     $options = array();
 
-    if (empty($form_state['exposed'])) {
+    if (empty($formState['exposed'])) {
       // Add a select all option to the value form.
       $options = array('all' => t('Select all'));
     }
 
     $this->getValueOptions();
-    $options += $this->value_options;
-    $default_value = (array) $this->value;
+    $options += $this->valueOptions;
+    $defaultValue = (array) $this->value;
 
     $which = 'all';
     if (!empty($form['operator'])) {
       $source = ':input[name="options[operator]"]';
     }
-    if (!empty($form_state['exposed'])) {
+    if (!empty($formState['exposed'])) {
       $identifier = $this->options['expose']['identifier'];
 
       if (empty($this->options['expose']['use_operator']) || empty($this->options['expose']['operator_id'])) {
@@ -196,21 +196,21 @@ protected function valueForm(&$form, &$form_state) {
         $options = $this->reduceValueOptions();
 
         if (!empty($this->options['expose']['multiple']) && empty($this->options['expose']['required'])) {
-          $default_value = array();
+          $defaultValue = array();
         }
       }
 
       if (empty($this->options['expose']['multiple'])) {
-        if (empty($this->options['expose']['required']) && (empty($default_value) || !empty($this->options['expose']['reduce']))) {
-          $default_value = 'All';
+        if (empty($this->options['expose']['required']) && (empty($defaultValue) || !empty($this->options['expose']['reduce']))) {
+          $defaultValue = 'All';
         }
-        elseif (empty($default_value)) {
+        elseif (empty($defaultValue)) {
           $keys = array_keys($options);
-          $default_value = array_shift($keys);
+          $defaultValue = array_shift($keys);
         }
         else {
-          $copy = $default_value;
-          $default_value = array_shift($copy);
+          $copy = $defaultValue;
+          $defaultValue = array_shift($copy);
         }
       }
     }
@@ -218,19 +218,19 @@ protected function valueForm(&$form, &$form_state) {
     if ($which == 'all' || $which == 'value') {
       $form['value'] = array(
         '#type' => $this->valueFormType,
-        '#title' => $this->value_title,
+        '#title' => $this->valueTitle,
         '#options' => $options,
-        '#default_value' => $default_value,
+        '#default_value' => $defaultValue,
         // These are only valid for 'select' type, but do no harm to checkboxes.
         '#multiple' => TRUE,
         '#size' => count($options) > 8 ? 8 : count($options),
       );
-      if (!empty($form_state['exposed']) && !isset($form_state['input'][$identifier])) {
-        $form_state['input'][$identifier] = $default_value;
+      if (!empty($formState['exposed']) && !isset($formState['input'][$identifier])) {
+        $formState['input'][$identifier] = $defaultValue;
       }
 
       if ($which == 'all') {
-        if (empty($form_state['exposed']) && (in_array($this->valueFormType, array('checkbox', 'checkboxes', 'radios', 'select')))) {
+        if (empty($formState['exposed']) && (in_array($this->valueFormType, array('checkbox', 'checkboxes', 'radios', 'select')))) {
           $form['value']['#prefix'] = '<div id="edit-options-value-wrapper">';
           $form['value']['#suffix'] = '</div>';
         }
@@ -249,7 +249,7 @@ protected function valueForm(&$form, &$form_state) {
    */
   public function reduceValueOptions($input = NULL) {
     if (!isset($input)) {
-      $input = $this->value_options;
+      $input = $this->valueOptions;
     }
 
     // Because options may be an array of strings, or an array of mixed arrays
@@ -294,7 +294,7 @@ public function acceptExposedInput($input) {
     return parent::acceptExposedInput($input);
   }
 
-  protected function valueSubmit($form, &$form_state) {
+  protected function valueSubmit($form, &$formState) {
     // Drupal's FAPI system automatically puts '0' in for any checkbox that
     // was not set, and the key to the checkbox if it is set.
     // Unfortunately, this means that if the key to that checkbox is 0,
@@ -304,7 +304,7 @@ protected function valueSubmit($form, &$form_state) {
     // *only* a list of checkboxes that were set, and we can use that
     // instead.
 
-    $form_state['values']['options']['value'] = $form['value']['#value'];
+    $formState['values']['options']['value'] = $form['value']['#value'];
   }
 
   public function adminSummary() {
@@ -327,7 +327,7 @@ public function adminSummary() {
     if (in_array($this->operator, $this->operatorValues(1))) {
       // Remove every element which is not known.
       foreach ($this->value as $value) {
-        if (!isset($this->value_options[$value])) {
+        if (!isset($this->valueOptions[$value])) {
           unset($this->value[$value]);
         }
       }
@@ -343,8 +343,8 @@ public function adminSummary() {
 
         $keys = $this->value;
         $value = array_shift($keys);
-        if (isset($this->value_options[$value])) {
-          $values = UtilityString::checkPlain($this->value_options[$value]);
+        if (isset($this->valueOptions[$value])) {
+          $values = UtilityString::checkPlain($this->valueOptions[$value]);
         }
         else {
           $values = '';
@@ -359,8 +359,8 @@ public function adminSummary() {
             $values .= '...';
             break;
           }
-          if (isset($this->value_options[$value])) {
-            $values .= UtilityString::checkPlain($this->value_options[$value]);
+          if (isset($this->valueOptions[$value])) {
+            $values .= UtilityString::checkPlain($this->valueOptions[$value]);
           }
         }
       }
@@ -413,7 +413,7 @@ public function validate() {
       $errors[] = t('The operator is invalid on filter: @filter.', array('@filter' => $this->adminLabel(TRUE)));
     }
     if (is_array($this->value)) {
-      if (!isset($this->value_options)) {
+      if (!isset($this->valueOptions)) {
         // Don't validate if there are none value options provided, for example for special handlers.
         return $errors;
       }
@@ -423,11 +423,11 @@ public function validate() {
       }
 
       // Some filter_in_operator usage uses optgroups forms, so flatten it.
-      $flat_options = form_options_flatten($this->value_options, TRUE);
+      $flatOptions = form_options_flatten($this->valueOptions, TRUE);
 
       // Remove every element which is not known.
       foreach ($this->value as $value) {
-        if (!isset($flat_options[$value])) {
+        if (!isset($flatOptions[$value])) {
           unset($this->value[$value]);
         }
       }
@@ -51,26 +51,26 @@ public function init(ViewExecutable $view, DisplayPluginBase $display, array &$o
    *
    * @return
-   *   Return the stored values in $this->value_options if someone expects it.
+   *   Return the stored values in $this->valueOptions if someone expects it.
    */
   public function getValueOptions() {